@@ -1624,28 +1624,28 @@ extern int as_mysql_nonhour_rollup(mysql_conn_t *mysql_conn,
 	uint16_t track_wckey = slurm_get_track_wckey();
 	char *unit_name;
 
-	if (!slurm_localtime_r(&curr_start, &start_tm)) {
-		error("Couldn't get localtime from start %ld", curr_start);
-		return SLURM_ERROR;
-	}
-
-	start_tm.tm_sec = 0;
-	start_tm.tm_min = 0;
-	start_tm.tm_hour = 0;
-	start_tm.tm_isdst = -1;
-
-	if (run_month) {
-		unit_name = "month";
-		start_tm.tm_mday = 1;
-		start_tm.tm_mon++;
-	} else {
-		unit_name = "day";
-		start_tm.tm_mday++;
-	}
-
-	curr_end = slurm_mktime(&start_tm);
-
 	while (curr_start < end) {
+		if (!slurm_localtime_r(&curr_start, &start_tm)) {
+			error("Couldn't get localtime from start %ld",
+			      curr_start);
+			return SLURM_ERROR;
+		}
+		start_tm.tm_sec = 0;
+		start_tm.tm_min = 0;
+		start_tm.tm_hour = 0;
+		start_tm.tm_isdst = -1;
+
+		if (run_month) {
+			unit_name = "month";
+			start_tm.tm_mday = 1;
+			start_tm.tm_mon++;
+		} else {
+			unit_name = "day";
+			start_tm.tm_mday++;
+		}
+
+		curr_end = slurm_mktime(&start_tm);
+
 		if (debug_flags & DEBUG_FLAG_DB_USAGE)
 			DB_DEBUG(mysql_conn->conn,
 				 "curr %s is now %ld-%ld",
@@ -1666,6 +1666,7 @@ extern int as_mysql_nonhour_rollup(mysql_conn_t *mysql_conn,
 			cluster_name,
 			run_month ? assoc_day_table : assoc_hour_table,
 			curr_end, curr_start, now);
+
 		/* We group on deleted here so if there are no entries
 		   we don't get an error, just nothing is returned.
 		   Else we get a bunch of NULL's
@@ -1726,17 +1727,6 @@ extern int as_mysql_nonhour_rollup(mysql_conn_t *mysql_conn,
 		}
 
 		curr_start = curr_end;
-		if (!slurm_localtime_r(&curr_start, &start_tm)) {
-			error("Couldn't get localtime from %s start %ld",
-			      unit_name, curr_start);
-			return SLURM_ERROR;
-		}
-		start_tm.tm_sec = 0;
-		start_tm.tm_min = 0;
-		start_tm.tm_hour = 0;
-		start_tm.tm_mday++;
-		start_tm.tm_isdst = -1;
-		curr_end = slurm_mktime(&start_tm);
 	}
 
 /* 	info("stop start %s", slurm_ctime2(&curr_start)); */
