@@ -83,6 +83,8 @@ enum {
 	GET_POWER
 };
 
+extern void acct_gather_energy_p_conf_set(s_p_hashtbl_t *tbl);
+
 static uint32_t _get_latest_stats(int type)
 {
 	uint32_t data = 0;
@@ -274,6 +276,12 @@ extern int acct_gather_energy_p_get_data(enum acct_energy_type data_type,
 
 	xassert(_run_in_daemon());
 
+	if (!local_energy) {
+		debug("%s: trying to get data %d, but no local_energy yet.",
+		      __func__, data_type);
+		acct_gather_energy_p_conf_set(NULL);
+	}
+
 	switch (data_type) {
 	case ENERGY_DATA_JOULES_TASK:
 	case ENERGY_DATA_NODE_ENERGY_UP:
@@ -338,6 +346,10 @@ extern void acct_gather_energy_p_conf_set(s_p_hashtbl_t *tbl)
 	if (!_run_in_daemon())
 		return;
 
+	/* Already been here, we shouldn't need to visit again */
+	if (local_energy)
+		return;
+
 	if (!flag_init) {
 		flag_init = 1;
 		local_energy = acct_gather_energy_alloc(1);
