@@ -50,7 +50,7 @@
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <strings.h>
-#include <sys/poll.h>
+#include <poll.h>
 #include <sys/time.h>
 
 #include <arpa/inet.h>
