@@ -51,7 +51,7 @@
 #endif
 
 #include <stdio.h>
-#include <sys/poll.h>
+#include <poll.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
