@@ -64,7 +64,7 @@
 #  include <utmp.h>
 #endif
 
-#include <sys/poll.h>
+#include <poll.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/stat.h>
