@@ -57,15 +57,6 @@ enum {
 	PRINT_RESV_TRES_USAGE,
 };
 
-typedef enum {
-	GROUP_BY_ACCOUNT,
-	GROUP_BY_ACCOUNT_JOB_SIZE,
-	GROUP_BY_ACCOUNT_JOB_SIZE_DURATION,
-	GROUP_BY_USER,
-	GROUP_BY_USER_JOB_SIZE,
-	GROUP_BY_USER_JOB_SIZE_DURATION,
-	GROUP_BY_NONE
-} report_grouping_t;
 
 static List print_fields_list = NULL; /* types are of print_field_t */
 
@@ -228,9 +219,9 @@ static int _setup_print_fields_list(List format_list)
 			if (time_format == SLURMDB_REPORT_TIME_SECS_PER
 			   || time_format == SLURMDB_REPORT_TIME_MINS_PER
 			   || time_format == SLURMDB_REPORT_TIME_HOURS_PER)
-				field->len = 20;
+				field->len = 29;
 			else
-				field->len = 9;
+				field->len = 20;
 			field->print_routine = slurmdb_report_print_time;
 		} else if (!strncasecmp("Associations",
 				       object, MAX(command_len, 2))) {
@@ -261,9 +252,9 @@ static int _setup_print_fields_list(List format_list)
 			if (time_format == SLURMDB_REPORT_TIME_SECS_PER
 			   || time_format == SLURMDB_REPORT_TIME_MINS_PER
 			   || time_format == SLURMDB_REPORT_TIME_HOURS_PER)
-				field->len = 20;
+				field->len = 29;
 			else
-				field->len = 9;
+				field->len = 20;
 			field->print_routine = slurmdb_report_print_time;
 		} else if (!strncasecmp("Name", object,
 				       MAX(command_len, 2))) {
